@@ -18,31 +18,32 @@ except ImportError:
     from yaml import Loader, Dumper
 
 def init_connection(test_instance, timeout=600):
-    if test_instance.params['remote_node'] is not None:
-        test_instance.log.info("remote_node specified, all tests will be run in {}".format(test_instance.params['remote_node']))
-        ssh = rmt_ssh.RemoteSSH()
-        ssh.rmt_node = test_instance.params['remote_node']
-        ssh.rmt_user = test_instance.params['remote_user']
-        ssh.rmt_password = test_instance.params['remote_password']
-        ssh.rmt_keyfile = test_instance.params['remote_keyfile']
-        ssh.timeout = 180
-        ssh.log = test_instance.log
-        test_instance.SSH = ssh
-        start_time = time.time()
-        while True:
-            current_time = time.time()
-            if current_time - start_time > timeout:
-                test_instance.log.info("timeout to connect to remote")
-                break
-            test_instance.SSH.create_connection()
-            if test_instance.SSH.ssh_client is not None:
-                break
-            time.sleep(5)
-            test_instance.log.info("Not conncted, retry again! timeout:{}".format(timeout))
-        if test_instance.SSH.ssh_client is None:
-            test_instance.skipTest("Cannot make ssh connection to remote, please check")
-    else:
-        test_instance.SSH.ssh_client = None
+    if test_instance.params['remote_node'] is None:
+        return
+
+    test_instance.log.info("remote_node specified, all tests will be run in {}".format(test_instance.params['remote_node']))
+    ssh = rmt_ssh.RemoteSSH()
+    ssh.rmt_node = test_instance.params['remote_node']
+    ssh.rmt_user = test_instance.params['remote_user']
+    ssh.rmt_password = test_instance.params['remote_password']
+    ssh.rmt_keyfile = test_instance.params['remote_keyfile']
+
+    ssh.timeout = 180
+    ssh.log = test_instance.log
+    test_instance.SSH = ssh
+    start_time = time.time()
+    while True:
+        current_time = time.time()
+        if current_time - start_time > timeout:
+            test_instance.log.info("timeout to connect to remote")
+            break
+        test_instance.SSH.create_connection()
+        if test_instance.SSH.ssh_client is not None:
+            break
+        time.sleep(5)
+        test_instance.log.info("Not conncted, retry again! timeout:{}".format(timeout))
+    if test_instance.SSH.ssh_client is None:
+        test_instance.skipTest("Cannot make ssh connection to remote, please check")
 
 def get_cfg():
     # Config file
@@ -50,6 +51,8 @@ def get_cfg():
     # Result dir
     with open(cfg_file,'r') as fh:
        keys_data = load(fh, Loader=Loader)
+    if os.path.exists(cfg_file):
+        print("{} config file found!".format(cfg_file))
     return cfg_file, keys_data
 
 def init_case(test_instance):
@@ -57,9 +60,7 @@ def init_case(test_instance):
     Arguments:
         test_instance {Test instance} -- unittest.TestCase instance
     """
-    cfg_file, keys_data = get_cfg()
-    test_instance.params = keys_data
-    results_dir = keys_data['results_dir']
+    results_dir = test_instance.params['results_dir']
     debug_dir = results_dir + "/debug"
     test_instance.log_dir = results_dir
     if not os.path.exists(results_dir):
@@ -91,11 +92,6 @@ def init_case(test_instance):
         init_connection(test_instance)
         if  test_instance.SSH.ssh_client is None:
             test_instance.skipTest("Cannot make ssh connection to remote, please check")
-    else:
-        test_instance.SSH = rmt_ssh.RemoteSSH()
-        test_instance.SSH.ssh_client = None
-    if os.path.exists(cfg_file):
-        test_instance.log.info("{} config file found!".format(cfg_file))
 
 def finish_case(test_instance):
     """init case
@@ -179,7 +175,7 @@ def run_cmd(test_instance,
     exception_hit = False
 
     try:
-        if  test_instance.SSH.ssh_client is not None:
+        if test_instance.params['remote_node'] is not None:
             status, output = test_instance.SSH.remote_excute(cmd, timeout, redirect_stdout=rmt_redirect_stdout, redirect_stderr=rmt_redirect_stderr,rmt_get_pty=rmt_get_pty)
         else:
             ret = subprocess.run(cmd, shell=True, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, timeout=timeout, encoding='utf-8')
@@ -597,7 +593,7 @@ def get_cmd_cursor(test_instance, cmd='dmesg -T', rmt_redirect_stdout=False, rmt
     test_instance.log.info("Get cursor: {}".format(cursor))
     return cursor
 
-def check_log(test_instance, log_keyword, log_cmd="journalctl -b 0", match_word_exact=False, cursor=None, skip_words=None, rmt_redirect_stdout=False, rmt_redirect_stderr=False, rmt_get_pty=False):
+def check_log(test_instance, log_keyword, log_cmd="journalctl -b 0", match_word_exact=False, cursor=None, skip_words=None, rmt_redirect_stdout=False, rmt_redirect_stderr=False, rmt_get_pty=False, msg=None):
     '''
     check journal log
     Arguments:
@@ -611,6 +607,8 @@ def check_log(test_instance, log_keyword, log_cmd="journalctl -b 0", match_word_
     # Baseline data file
     baseline_file = os.path.dirname(os_tests.__file__) + "/data/baseline_log.json"
     # Result dir
+    if msg is not None:
+        test_instance.log.info(msg)
     with open(baseline_file,'r') as fh:
         test_instance.log.info("Loading baseline data file from {}".format(baseline_file))
         baseline_dict = json.load(fh)
@@ -712,11 +710,13 @@ def find_word(test_instance, check_str, log_keyword, baseline_dict=None, skip_wo
     # compare 2 string, if similary over fail_rate, consider it as same.
     fail_rate = 70
     no_fail = True
+    check_done = False
     for line1 in tmp_list:
         find_it = False
         if baseline_dict is not None:
             for basekey in baseline_dict:
                 for sub_basekey_content in baseline_dict[basekey]["content"].split(';'):
+                    check_done = False
                     if re.search(sub_basekey_content, line1):
                         if baseline_dict[basekey]["status"] == 'active':
                             test_instance.log.info("Found a similar issue matched in baseline.")
@@ -725,6 +725,14 @@ def find_word(test_instance, check_str, log_keyword, baseline_dict=None, skip_wo
                             test_instance.log.info("Found a similar issue matched in baseline. But it is not active, please check manually")
                             find_it = False
                             no_fail = False
+                            check_done = True
+                            break
+                        if baseline_dict[basekey]["trigger"] in check_str and len(baseline_dict[basekey]["trigger"]) > 3:
+                            test_instance.log.info("Guess it is expected because trigger keywords found '{}'".format(baseline_dict[basekey]["trigger"]))
+                            find_it = True
+                        elif len(baseline_dict[basekey]["trigger"]) > 3:
+                            test_instance.log.info("Guess it is unexpected because trigger keywords not found '{}'".format(baseline_dict[basekey]["trigger"]))
+                            find_it = False
                         test_instance.log.info("log:{}, base:{}".format(line1, sub_basekey_content))
                         test_instance.log.info("ID:%s Baseline analyze:%s Branch:%s Status:%s Link:%s Path:%s" %
                              (basekey,
@@ -733,8 +741,9 @@ def find_word(test_instance, check_str, log_keyword, baseline_dict=None, skip_wo
                               baseline_dict[basekey]["status"],
                               baseline_dict[basekey]["link"],
                               baseline_dict[basekey]["path"]))
+                        check_done = True
                         break
-                if find_it:
+                if find_it or check_done:
                     break
                 line1_tmp = line1
                 line2_tmp = baseline_dict[basekey]["content"]
@@ -754,9 +763,13 @@ def find_word(test_instance, check_str, log_keyword, baseline_dict=None, skip_wo
                               baseline_dict[basekey]["status"],
                               baseline_dict[basekey]["link"],
                               baseline_dict[basekey]["path"]))
-                    if baseline_dict[basekey]["trigger"] in check_str and len(baseline_dict[basekey]["trigger"]) > 2:
-                        test_instance.log.info("Maybe it is expected because found '{}' too".format(baseline_dict[basekey]["trigger"]))
+                    if baseline_dict[basekey]["trigger"] in check_str and len(baseline_dict[basekey]["trigger"]) > 3:
+                        test_instance.log.info("Guess it is expected because trigger keywords found '{}'".format(baseline_dict[basekey]["trigger"]))
                         find_it = True
+                    elif len(baseline_dict[basekey]["trigger"]) > 3:
+                        test_instance.log.info("Guess it is unexpected because trigger keywords not found '{}'".format(baseline_dict[basekey]["trigger"]))
+                        find_it = False
+                        break
                     if baseline_dict[basekey]["status"] == 'active':
                         find_it = True
                     else:
@@ -772,8 +785,14 @@ def find_word(test_instance, check_str, log_keyword, baseline_dict=None, skip_wo
     return no_fail
 
 def get_product_id(test_instance):
-    check_cmd = "sudo cat /etc/redhat-release"
-    output = run_cmd(test_instance,check_cmd, expect_ret=0, msg='check release name')
-    product_id = re.findall('[\d.]{2,3}', output)[0]
+    cmd = "source /etc/os-release ;echo $VERSION_ID"
+    product_id = run_cmd(test_instance,cmd, expect_ret=0, msg='check release name')
     test_instance.log.info("Get product id: {}".format(product_id))
-    return product_id
\ No newline at end of file
+    return product_id
+
+def get_os_release_info(test_instance, field="VERSION_ID"):
+    data_file = '/etc/os-release'
+    cmd = "source {} ;echo ${}".format(data_file, field)
+    output = run_cmd(test_instance,cmd, expect_ret=0, msg='get {} from {}'.format(field, data_file))
+    test_instance.log.info("Got: {}".format(output))
+    return output
\ No newline at end of file
